Research Poster Template - 36x48 inches

# Your Research Title Here

Author One¹*, Author Two², Author Three¹

¹University of Example · ²Research Institute

## Introduction

Background: Context about your research problem.

Objective: What you aimed to accomplish.

## Methods

- Study design overview
- Key methodology
- Analysis approach

## Results

Key Finding: Your main result in one sentence

- Finding 1: Description (p < 0.001)
- Finding 2: Description with effect size

## Discussion

- Interpretation of findings
- Comparison to prior work
- Practical applications

## Conclusions

- Conclusion 1: Clear takeaway
- Conclusion 2: Clear takeaway
- Future: Next steps

## Acknowledgments

Funded by Grant #XXX. Thanks to collaborators.